@@ -17,11 +17,11 @@ class Logger:
                 handlers={
                     'h': {'class': 'logging.StreamHandler',
                           'formatter': 'f',
-                          'level': logging.DEBUG}
+                          'level': logging.INFO}
                 },
                 root={
                     'handlers': ['h'],
-                    'level': logging.DEBUG,
+                    'level': logging.INFO,
                 },
             )
 
