@@ -15,8 +15,6 @@ class SessionHandler:
 
         self.secret_key = secrets.token_urlsafe()
 
-        self._dict = {}
-
         self.initialized = False
 
     def init_session(self, request, response):
@@ -31,9 +29,9 @@ class SessionHandler:
 
         self.initialized = True
 
-    def __call__(self, request):
+    def __call__(self):
         assert self.initialized, "Session Not Initialized"
-        return self._dict[request.cookies.get("secret_key")]
+        return self._dict
 
 
 # class SessionMiddleware(Middleware):
